@@ -1,5 +1,5 @@
 /* URL handling.
-   Copyright (C) 1996-2011, 2015, 2018-2022 Free Software Foundation,
+   Copyright (C) 1996-2011, 2015, 2018-2024 Free Software Foundation,
    Inc.
 
 This file is part of GNU Wget.
@@ -670,25 +670,32 @@ init_seps (enum url_scheme scheme)
   return seps;
 }
 
+enum {
+    PE_NO_ERROR = 0,
+    PE_UNSUPPORTED_SCHEME,
+    PE_UNSUPPORTED_SCHEME_HTTPS,
+    PE_UNSUPPORTED_SCHEME_FTPS,
+    PE_MISSING_SCHEME,
+    PE_INVALID_HOST_NAME,
+    PE_BAD_PORT_NUMBER,
+    PE_INVALID_USER_NAME,
+    PE_UNTERMINATED_IPV6_ADDRESS,
+    PE_IPV6_NOT_SUPPORTED,
+    PE_INVALID_IPV6_ADDRESS
+};
+
 static const char *parse_errors[] = {
-#define PE_NO_ERROR                     0
-  N_("No error"),
-#define PE_UNSUPPORTED_SCHEME           1
-  N_("Unsupported scheme %s"), /* support for format token only here */
-#define PE_MISSING_SCHEME               2
-  N_("Scheme missing"),
-#define PE_INVALID_HOST_NAME            3
-  N_("Invalid host name"),
-#define PE_BAD_PORT_NUMBER              4
-  N_("Bad port number"),
-#define PE_INVALID_USER_NAME            5
-  N_("Invalid user name"),
-#define PE_UNTERMINATED_IPV6_ADDRESS    6
-  N_("Unterminated IPv6 numeric address"),
-#define PE_IPV6_NOT_SUPPORTED           7
-  N_("IPv6 addresses not supported"),
-#define PE_INVALID_IPV6_ADDRESS         8
-  N_("Invalid IPv6 numeric address")
+  [PE_NO_ERROR] = N_("No error"),
+  [PE_UNSUPPORTED_SCHEME] = N_("Unsupported scheme"),
+  [PE_UNSUPPORTED_SCHEME_HTTPS] = N_("HTTPS support not compiled in"),
+  [PE_UNSUPPORTED_SCHEME_FTPS] = N_("FTPS support not compiled in"),
+  [PE_MISSING_SCHEME] = N_("Scheme missing"),
+  [PE_INVALID_HOST_NAME] = N_("Invalid host name"),
+  [PE_BAD_PORT_NUMBER] = N_("Bad port number"),
+  [PE_INVALID_USER_NAME] = N_("Invalid user name"),
+  [PE_UNTERMINATED_IPV6_ADDRESS] = N_("Unterminated IPv6 numeric address"),
+  [PE_IPV6_NOT_SUPPORTED] = N_("IPv6 addresses not supported"),
+  [PE_INVALID_IPV6_ADDRESS] = N_("Invalid IPv6 numeric address")
 };
 
 /* Parse a URL.
@@ -723,10 +730,14 @@ url_parse (const char *url, int *error, struct iri *iri, bool percent_encode)
   scheme = url_scheme (url);
   if (scheme == SCHEME_INVALID)
     {
-      if (url_has_scheme (url))
-        error_code = PE_UNSUPPORTED_SCHEME;
-      else
+      if (!url_has_scheme (url))
         error_code = PE_MISSING_SCHEME;
+      else if (!c_strncasecmp (url, "https:", 6))
+        error_code = PE_UNSUPPORTED_SCHEME_HTTPS;
+      else if (!c_strncasecmp (url, "ftps:", 5))
+        error_code = PE_UNSUPPORTED_SCHEME_FTPS;
+      else
+        error_code = PE_UNSUPPORTED_SCHEME;
       goto error;
     }
 
@@ -990,29 +1001,15 @@ url_parse (const char *url, int *error, struct iri *iri, bool percent_encode)
 /* Return the error message string from ERROR_CODE, which should have
    been retrieved from url_parse.  The error message is translated.  */
 
-char *
-url_error (const char *url, int error_code)
+const char *
+url_error (int error_code)
 {
-  assert (error_code >= 0 && ((size_t) error_code) < countof (parse_errors));
+  assert (error_code >= 0 && error_code < (int) countof (parse_errors));
 
-  if (error_code == PE_UNSUPPORTED_SCHEME)
-    {
-      char *error, *p;
-      char *scheme = xstrdup (url);
-      assert (url_has_scheme (url));
+  if (error_code >= 0 && error_code < (int) countof (parse_errors))
+    return _(parse_errors[error_code]);
 
-      if ((p = strchr (scheme, ':')))
-        *p = '\0';
-      if (!c_strcasecmp (scheme, "https"))
-        error = aprintf (_("HTTPS support not compiled in"));
-      else
-        error = aprintf (_(parse_errors[error_code]), quote (scheme));
-      xfree (scheme);
-
-      return error;
-    }
-  else
-    return xstrdup (_(parse_errors[error_code]));
+  return ""; // This should never be reached
 }
 
 /* Split PATH into DIR and FILE.  PATH comes from the URL and is
@@ -2528,6 +2525,33 @@ test_are_urls_equal(void)
   return NULL;
 }
 
+const char *
+test_uri_merge(void)
+{
+  static const struct test_data {
+    const char *url;
+    const char *link;
+    const char *expected;
+  } test_data[] = {
+    { "http://www.yoyodyne.com/path/", "somepage.html", "http://www.yoyodyne.com/path/somepage.html" },
+    { "http://example.com/path/", "//other.com/somepage.html", "http://other.com/somepage.html" },
+    { "https://example.com/path/", "//other.com/somepage.html", "https://other.com/somepage.html" },
+  };
+
+  for (unsigned i = 0; i < countof(test_data); ++i)
+    {
+      const struct test_data *t = &test_data[i];
+      char *result = uri_merge (t->url, t->link);
+      bool ok = strcmp (result, t->expected) == 0;
+      if (!ok)
+        return aprintf ("test_uri_merge [%u]: expected '%s', got '%s'", i, t->expected, result);
+
+      xfree (result);
+    }
+
+  return NULL;
+}
+
 #endif /* TESTING */
 
 /*
